@@ -19,6 +19,7 @@ from qctrlcommons.node.registry import (
     TYPE_REGISTRY,
 )
 
+from qctrl import toolkit
 from qctrl.utils import PackageRegistry
 
 from .async_result import AsyncResult
@@ -90,9 +91,7 @@ def build_and_bind_namespaces(qctrl: "Qctrl") -> None:
 
     setattr(qctrl, "functions", function_namespace)
     setattr(qctrl, "types", type_namespace)
-    if PackageRegistry.QCTRLTOOLKIT.is_installed():
-        toolkit = PackageRegistry.QCTRLTOOLKIT.import_pkg()
-        build_and_bind_toolkit(qctrl, ToolkitCategory.WORKFLOWS, toolkit)
+    build_and_bind_toolkit(qctrl, ToolkitCategory.FUNCTIONS, toolkit)
 
 
 __all__ = ["build_and_bind_namespaces"]
