@@ -1,11 +1,11 @@
-# Copyright 2021 Q-CTRL. All rights reserved.
+# Copyright 2022 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
 # Proprietary and confidential. You may not use this file except in compliance
 # with the License. You may obtain a copy of the License at
 #
-#     https://q-ctrl.com/terms
+#    https://q-ctrl.com/terms
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS. See the
@@ -49,9 +49,7 @@ LOGGER = logging.getLogger(__name__)
 
 
 def build_function(
-    qctrl: "Qctrl",
-    mutation_name: str,
-    mutation_field: GraphQLField,
+    qctrl: "Qctrl", mutation_name: str, mutation_field: GraphQLField
 ) -> Callable:
     """Returns a function which can be used to execute a GraphQL mutation.
 
@@ -76,10 +74,7 @@ def build_function(
 
     def get_query(**kwargs) -> StartActionQuery:
         return qctrl.gql_env.build_mutation_query(
-            mutation_name,
-            input_type,
-            mutation_field.type,
-            kwargs,
+            mutation_name, input_type, mutation_field.type, kwargs
         )
 
     def func(**kwargs):
@@ -122,11 +117,7 @@ def build_function(
     func.__name__ = _get_function_name(mutation_name)
 
     # build signature and sign function
-    signature = build_signature(
-        qctrl.gql_env,
-        input_type,
-        mutation_field.type,
-    )
+    signature = build_signature(qctrl.gql_env, input_type, mutation_field.type)
 
     func = signature(func)
 
@@ -199,10 +190,7 @@ def build_signature(
         returns = _get_type_hint(env, return_type, base=ResultMixin)
 
         if returns is not forge.FParameter.empty:
-            signature = forge.compose(
-                signature,
-                forge.returns(returns),
-            )
+            signature = forge.compose(signature, forge.returns(returns))
 
     return signature
 
