@@ -69,7 +69,7 @@ class Qctrl:
     Creating an instance of this class requires authentication with Q-CTRL's API.
 
     The recommended method of authentication is through the interactive authentication
-    method. This method can be invoked by simply calling Qctrl() without any arguments.
+    method. This method can be invoked by simply calling `Qctrl()` without any arguments.
     This method will also create an authentication file that will be used for subsequent
     authentications when using the package.
 
@@ -77,6 +77,11 @@ class Qctrl:
 
       qctrl = Qctrl()
 
+    You can also access toolkits provided by Boulder Opal through the corresponding namespaces
+    of the Qctrl object.
+    See the `reference <https://docs.q-ctrl.com/boulder-opal/references/qctrl/Toolkits.html>`_
+    for details.
+
     .. deprecated:: 15.4.4
           Email and password based authentication has been removed in favour of
           url based authentication. To authenticate simply call `qctrl = Qctrl()`
