@@ -230,7 +230,6 @@ def check_client_version(func):
 # imported when locally available
 _PackageInfo = namedtuple("_PackageInfo", ["name", "pkg_name", "url"])
 _QCTRL_URL = "https://pypi.org/pypi/qctrl/json"
-_TOOLKIT_URL = "https://pypi.org/pypi/qctrl-toolkit/json"
 
 
 class PackageRegistry(Enum):
@@ -239,7 +238,6 @@ class PackageRegistry(Enum):
     """
 
     QCTRL = _PackageInfo("Q-CTRL", "qctrl", _QCTRL_URL)
-    QCTRLTOOLKIT = _PackageInfo("Q-CTRL Toolkit", "qctrltoolkit", _TOOLKIT_URL)
 
     def check_latest_version(self):
         """
